Documentation
¶
Overview ¶
Package elide provides basic text eliding functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppName ¶ added in v0.3.2
AppName elides the given app name to be twelve characters or less by removing word(s) from the middle of the string if necessary and possible.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.