Documentation
¶
Overview ¶
Package gzipx provides a convenience wrapper for gzip encoding for reader and writer.
Index ¶
- func Open(filename string, fun func(gzr io.Reader) error) error
- func OpenFS(fsys fs.FS, filename string, fun func(gzr io.Reader) error) error
- func Read(r io.Reader, fun func(gzr io.Reader) error) error
- func Save(filename string, fun func(gzw io.Writer) error) error
- func Write(w io.Writer, fun func(gzw io.Writer) error) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Open ¶
Open opens given file and calls the given function on it, first detecting whether the filename has a .gz extension, and adding an gzip reader if so.
func OpenFS ¶
OpenFS opens given file from filesystem and calls the given function on it, first detecting whether the filename has a .gz extension, and adding a gzip reader if so.
func Read ¶
Read adds a gzip reader to the given reader, and calls the given function with the unzip reader, returning the error from that function.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.